###############################################################################
#	Filename:	Skeleton.py
#	By:		edtheborg
###############################################################################
# This file is a torpedo skeleton for using the Script Torpedo Mod
#
# The TargetHit() procedure is called whenever This torpedo hits a target
# The WeaponFired() procedure is called whenever This torpedo is fired
#
# refer to ChronotonTorpedo.py, HyperonTorpedo.py, and PhasedTorp.py to
# find out how to get the target that was hit, or the ship that fired the weapon
#
# (if you are not new to scripting in bridge commander you already know how to get that info)
###############################################################################

import App

###############################################################################
#	Args:	pTorp - the torpedo, ready to be filled-in
#	
#	Return:	zero
###############################################################################
def Create(pTorp):
	kCoreColor = App.TGColorA()
	kCoreColor.SetRGBA(240.0 / 255.0, 0.0 / 255.0, 15.0 / 255.0, 1.000000)
	kGlowColor = App.TGColorA()
	kGlowColor.SetRGBA(100.0 / 255.0, 40.0 / 255.0, 40.0 / 255.0, 1.000000)
	kFlareColor = App.TGColorA()
	kFlareColor.SetRGBA(80.0 / 255.0, 60.0 / 255.0, 70.0 / 255.0, 1.000000)		

	pTorp.CreateTorpedoModel(
					"data/Textures/Tactical/TorpedoCore.tga",
					kCoreColor,
					0.2,
					1.0,	 
					"data/Textures/Tactical/TorpedoGlow.tga", 
					kGlowColor,
					4.0,	
					0.2,	 
					0.7,	
					"data/Textures/Tactical/TorpedoFlares.tga",
					kFlareColor,										
					6,		
					0.7,		
					0.4)

	pTorp.SetDamage( GetDamage() )
	pTorp.SetDamageRadiusFactor(0.19)
	pTorp.SetGuidanceLifetime( GetGuidanceLifetime() )
	pTorp.SetMaxAngularAccel( GetMaxAngularAccel() )

	# Multiplayer specific stuff.  Please, if you create a new torp
	# type. modify the SpeciesToTorp.py file to add the new type.
	import Multiplayer.SpeciesToTorp
	pTorp.SetNetType (Multiplayer.SpeciesToTorp.PHASEDPLASMA)

	return(0)

def GetLaunchSpeed():
	return(12)

def GetLaunchSound():
	return("Fill In")

def GetPowerCost():
	return(40.0)

def GetName():
	return("Fill In")

def GetDamage():
	return 0.00001

def GetGuidanceLifetime():
	return 10.0

def GetMaxAngularAccel():
	return 0.11

def TargetHit(pObject, pEvent):
	return

def WeaponFired(pObject, pEvent):
	return
